package de.thd.pms.controller;


import java.beans.JavaBean;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;
import de.thd.pms.model.Buchung;
import de.thd.pms.model.Zimmer;
import de.thd.pms.service.BuchungService;
import de.thd.pms.service.KundeService;
import de.thd.pms.service.ZimmerService;

@JavaBean
@Controller
@RequestMapping ("/buchung")
public class BuchungController {
	private static Logger log = LogManager.getLogger(BuchungController.class);

	@Autowired
	private BuchungService buchungService;
	
	@Autowired
	private ZimmerService zimmerService;
	
    @Autowired
	private KundeService kundeService;
	
	
	@RequestMapping(value="/edit2", method=RequestMethod.GET)
    public ModelAndView edit(@RequestParam(required=true) Long zimmerid, Long kundenid) {
    	log.debug("edit id=" + zimmerid);
    	ModelAndView mv = new ModelAndView();
    	mv.addObject(new Buchung(zimmerid));
    	mv.addObject("title", "Buchung");
		mv.addObject("message", "Bitte geben Sie hier Ihre Buchungsdaten ein und bestätigen die Buchung durch den Button 'Buchen'");
		mv.addObject("anzbettErw", zimmerService.findById(zimmerid).getAnzBettErwArray());
		mv.addObject("anzbettKind", zimmerService.findById(zimmerid).getAnzBettKindArray());
		mv.addObject("zimmer", zimmerService.findById(zimmerid));
		mv.addObject("kunden", kundeService.findById(kundenid));
    	mv.setViewName("buchung");
    	return mv;
    }
	
    @RequestMapping(value="/stornieren", method=RequestMethod.GET)
    public ModelAndView stornieren() {
		ModelAndView mv = new ModelAndView();
		mv.setViewName("stornieren");
		return mv;
    }
	
	
	@RequestMapping(value="/save2", method=RequestMethod.GET)
    public ModelAndView save(Buchung buchung, Model model) {
        
        buchungService.save(buchung);
        
        model.addAttribute("statusMessageKey", "buchung.form.msg.success");
        return new ModelAndView("redirect:berechnung?buchungid=" + buchung.getId());
    }

	@RequestMapping(value="/berechnung", method=RequestMethod.GET)
    public ModelAndView berechnung(Long buchungid) {
		ModelAndView mv = new ModelAndView();
		Buchung b = buchungService.findById(buchungid); 
		Zimmer z = zimmerService.findById(b.getZimmerid());
        
		b.setPreissum(z.getPreisErw()*b.getErwa_anz()+z.getPreisKind()*b.getKind_anz()) ;
		
		buchungService.save(b);
		mv.addObject("buchung", buchungService.findById(buchungid));
		mv.addObject("zimmer", zimmerService.findById(b.getZimmerid()));
		mv.addObject("kunde", kundeService.findById(b.getKundenid()));
		mv.setViewName("bestaetigung");
        return mv;
    }
	
	
	
    @RequestMapping(value="/findAll", method=RequestMethod.GET)
    public ModelAndView findAll() {
		ModelAndView mv = new ModelAndView();
		mv.addObject("title", "Zimmer");
		mv.addObject("message", "Hier finden Sie unsere Auswahl an Zimmer. Zum starten der Buchung drücken Sie bitte auf den gewünschte Zimmernamen");
		mv.addObject("zimmer", zimmerService.findAll());
		mv.setViewName("list-zimmer");
		return mv;
    }
    
    @RequestMapping(value="/delete", method=RequestMethod.GET)
    public String delete(@RequestParam(required=true) Long buchungid) {
    		Buchung b = buchungService.findById(buchungid);
    		
			buchungService.delete(buchungid);
			kundeService.delete(b.getKundenid());
			return "redirect:/welcome";
		}
	
}
